@@ -118,7 +118,7 @@ class HeadlessMode:
 
         self.li.shell.set_prompt(str(self.prompt))
 
-        self.li.shell.set_variable("env", self.shell_env)
+        self.li.shell.set_variable("env", self.shell_env.env)
         self.li.shell.set_variable("environ", os.environ)
 
         self.shell_env.validate()
